@@ -1,7 +1,27 @@
+/*	
+ *   xtel - Emulateur MINITEL sous X11
+ *
+ *   Copyright (C) 1991-1994  Lectra Systemes & Pierre Ficheux
+ *
+ *   This program is free software; you can redistribute it and/or modify
+ *   it under the terms of the GNU General Public License as published by
+ *   the Free Software Foundation; either version 2 of the License, or
+ *   (at your option) any later version.
+ *
+ *   This program is distributed in the hope that it will be useful,
+ *   but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *   GNU General Public License for more details.
+ *
+ *   You should have received a copy of the GNU General Public License
+ *   along with this program; if not, write to the Free Software
+ *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ */
+static char rcsid[] = "$Id: xvdt.c,v 1.3 1996/09/22 16:56:29 pierre Exp $";
+
 /*
  * Test du widget Videotex
  */
-static char rcsid[] = "$Id: xvdt.c,v 1.2 1994/09/21 17:10:51 pierre Exp $";
  
 #include <stdio.h>
 #include <fcntl.h>
@@ -33,6 +53,7 @@ XButtonEvent *pevent;
     fd = open (client_data, O_RDONLY);
     
     if (fd > 0) {
+	XtVaSetValues (w, XtNfdConnexion, fd, NULL);
 	videotexDecode (w, 12);
 	while (read (fd, &c, 1) > 0)
 	    videotexDecode (w, c);
@@ -63,8 +84,3 @@ char **av;
     XtRealizeWidget(toplevel);
     XtAppMainLoop (app_context);
 }
-
-
-
-
-
