@@ -15,7 +15,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: XpmButton.c,v 1.2 1996/10/04 17:03:16 pierre Exp $";
+static char rcsid[] = "$Id: XpmButton.c,v 1.4 1997/02/21 17:12:20 pierre Exp $";
 
 /*
  * XpmButton, a simple push/toggle button widget with a nice 
@@ -177,6 +177,7 @@ Cardinal *num_args;		/* unused */
   XpmButtonWidget xbw = (XpmButtonWidget) new;
   int rab, width, height;
   Window root;
+  XGCValues	values;
 
   /* If no Pixmap defined, use the default ;-) */
   if (xbw->xpmbutton.pixmap1 == None) {
@@ -200,11 +201,11 @@ Cardinal *num_args;		/* unused */
   xbw->core.width = width + 2 * xbw->xpmbutton.shadow_thickness;
   xbw->core.height = height + 2 * xbw->xpmbutton.shadow_thickness;
 
-  xbw->xpmbutton.normal_GC = XtGetGC(new, 0, NULL);
-  xbw->xpmbutton.color1_GC = XtGetGC(new, 0, NULL);
-  XSetForeground (XtDisplay(new), xbw->xpmbutton.color1_GC, xbw->xpmbutton.shadow_color1);
-  xbw->xpmbutton.color2_GC = XtGetGC(new, 0, NULL);
-  XSetForeground (XtDisplay(new), xbw->xpmbutton.color2_GC, xbw->xpmbutton.shadow_color2);
+  xbw->xpmbutton.normal_GC = XCreateGC (XtDisplay(new), RootWindowOfScreen(XtScreen(new)), 0, NULL);
+  values.foreground = xbw->xpmbutton.shadow_color1;
+  xbw->xpmbutton.color1_GC = XtGetGC(new, (unsigned) GCForeground, &values);
+  values.foreground = xbw->xpmbutton.shadow_color2;
+  xbw->xpmbutton.color2_GC = XtGetGC(new, (unsigned) GCForeground, &values);
 
   /* Create the Help window ? */
   if (xbw->xpmbutton.help_string) {
@@ -247,7 +248,8 @@ Pixmap pixmap, shape;
 	XClearWindow(XtDisplay(w), XtWindow(w));
 	
 	if (!XtIsSensitive (w)) {
-	    XSetClipMask(XtDisplay(w), gc, xbw->xpmbutton.unsensitive_bitmap);
+	    if (xbw->xpmbutton.unsensitive_bitmap != None)
+		XSetClipMask(XtDisplay(w), gc, xbw->xpmbutton.unsensitive_bitmap);
 	}
 	else {
 	    if (shape != None) {
@@ -314,7 +316,6 @@ XtIntervalId *id;
     XRaiseWindow (XtDisplay(w), xbw->xpmbutton.help_window);
     XMapWindow (XtDisplay(w), xbw->xpmbutton.help_window);
     XDrawImageString (XtDisplay(w), xbw->xpmbutton.help_window, xbw->xpmbutton.help_GC, 2, xbw->xpmbutton.help_font->max_bounds.ascent+2, xbw->xpmbutton.help_string, strlen(xbw->xpmbutton.help_string));
-    (void)XtAppAddTimeOut (XtWidgetToApplicationContext((Widget)w), (unsigned long)1000, (XtTimerCallbackProc)hide_help, (XtPointer)w);
 }
 
 static void arm_help (xbw)
@@ -443,7 +444,7 @@ Destroy(w)
 Widget w;
 {
   XpmButtonWidget xbw = (XpmButtonWidget) w;
-  XtReleaseGC (w, xbw->xpmbutton.normal_GC);
+  XFreeGC (XtDisplay(w), xbw->xpmbutton.normal_GC);
   XtReleaseGC (w, xbw->xpmbutton.color1_GC);
   XtReleaseGC (w, xbw->xpmbutton.color2_GC);
   XtReleaseGC (w, xbw->xpmbutton.help_GC);
