@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xaw.c,v 1.15 1996/10/31 12:59:34 pierre Exp $";
+static char rcsid[] = "$Id: xaw.c,v 1.17 1997/02/21 17:00:30 pierre Exp $";
 
 /*
  * Couche Toolkit ATHENA
@@ -199,6 +199,7 @@ static Widget popup_lecteur, forme_lecteur, play_lecteur, stop_lecteur, wind_lec
 static Widget rewind_lecteur, zero_lecteur;
 static Widget arret_lecteur_popup;
 static Widget type_arret_lecteur, arret_none, arret_form_feed, arret_suite;
+static Widget arret_suite_ou_ff;
 static Widget menu_aide, bouton_aide;
 static Widget menu_proto, paned_base;
 #ifndef LOW_MEMORY
@@ -259,6 +260,11 @@ XtPointer call_data;
 	   type_de_fin_page = ARRET_SUITE;
 	  XtVaGetValues (arret_suite, XtNlabel, &value, NULL);
 	  break;
+
+	case 3 :
+	   type_de_fin_page = ARRET_SUITE | ARRET_FF;
+	  XtVaGetValues (arret_suite_ou_ff, XtNlabel, &value, NULL);
+	  break;
 	  
 	default :
 	    return;
@@ -327,8 +333,8 @@ char *name;
 WidgetClass class;
 void *cb;
 XtPointer call_data;
-char *pixmap1_data[], *pixmap2_data[];
-char *shape1_data[], *shape2_data[];
+char **pixmap1_data, **pixmap2_data;
+char **shape1_data, **shape2_data;
 Pixmap unsensitive_bitmap;
 {
     Widget w;
@@ -717,11 +723,11 @@ Widget topLevel;
 	}
 #ifndef LOW_MEMORY
     else {
-	zero_lecteur = create_pixmap_button (forme_lecteur, "zero_lecteur", xpmButtonWidgetClass, (XtCallbackProc)Zero_lecteur, (XtPointer)NULL, rewind_xpm, None, None, None, None, NULL);
-	rewind_lecteur = create_pixmap_button (forme_lecteur, "rewind_lecteur", xpmButtonWidgetClass, Rewind_lecteur, (XtPointer)NULL, prev_xpm, None, None, None, None, NULL);
-	stop_lecteur = create_pixmap_button (forme_lecteur, "stop_lecteur", xpmToggleWidgetClass, Stop_lecteur, (XtPointer)NULL, stop_xpm, None, None, None, None, NULL);
-	play_lecteur = create_pixmap_button (forme_lecteur, "play_lecteur", xpmToggleWidgetClass, Play_lecteur, (XtPointer)NULL, play_xpm, None, None, None, None, NULL); 
-	wind_lecteur = create_pixmap_button (forme_lecteur, "wind_lecteur", xpmButtonWidgetClass, Wind_lecteur, (XtPointer)NULL, next_xpm, None, None, None, None, NULL);
+	zero_lecteur = create_pixmap_button (forme_lecteur, "zero_lecteur", xpmButtonWidgetClass, (XtCallbackProc)Zero_lecteur, (XtPointer)NULL, rewind_xpm, NULL, NULL, NULL, None);
+	rewind_lecteur = create_pixmap_button (forme_lecteur, "rewind_lecteur", xpmButtonWidgetClass, Rewind_lecteur, (XtPointer)NULL, prev_xpm, NULL, NULL, NULL, None);
+	stop_lecteur = create_pixmap_button (forme_lecteur, "stop_lecteur", xpmToggleWidgetClass, Stop_lecteur, (XtPointer)NULL, stop_xpm, NULL, NULL, NULL, None);
+	play_lecteur = create_pixmap_button (forme_lecteur, "play_lecteur", xpmToggleWidgetClass, Play_lecteur, (XtPointer)NULL, play_xpm, NULL, NULL, NULL, None);
+	wind_lecteur = create_pixmap_button (forme_lecteur, "wind_lecteur", xpmButtonWidgetClass, Wind_lecteur, (XtPointer)NULL, next_xpm, NULL, NULL, NULL, None);
     }
 #endif /* !LOW_MEMORY */
 
@@ -742,6 +748,9 @@ Widget topLevel;
     XtAddCallback (arret_form_feed, XtNcallback, (XtCallbackProc)menu_type_arret_page_cb, (XtPointer)1);
     arret_suite = XtVaCreateManagedWidget ("arret_suite", smeBSBObjectClass, arret_lecteur_popup, NULL);
     XtAddCallback (arret_suite, XtNcallback, (XtCallbackProc)menu_type_arret_page_cb, (XtPointer)2);
+    arret_suite_ou_ff = XtVaCreateManagedWidget ("arret_suite_ou_ff", smeBSBObjectClass, arret_lecteur_popup, NULL);
+    XtAddCallback (arret_suite_ou_ff, XtNcallback, (XtCallbackProc)menu_type_arret_page_cb, (XtPointer)3);
+
 
     /* le bouton pour quitter */
     quitte_lecteur = create_text_button (forme_lecteur, "quitte_lecteur", commandWidgetClass, fin_lecteur, (XtPointer)NULL);
@@ -788,7 +797,7 @@ Widget topLevel;
 	
       /* Quitter */
       btn_quitte = create_pixmap_button (boite_haut, "btn_quitte", xpmButtonWidgetClass, Selection_menu_fichier, (XtPointer)QUITTE, door_run_xpm, None, None, None, unsensitive_pixmap_h);
-      la_cassete = create_pixmap_button (boite_haut, "la_cassete", xpmButtonWidgetClass, NULL, NULL, cassete_xpm, None, None, None, None, NULL);
+      la_cassete = create_pixmap_button (boite_haut, "la_cassete", xpmButtonWidgetClass, NULL, NULL, cassete_xpm, NULL, NULL, NULL, None);
       XtVaSetValues (la_cassete, XtNmappedWhenManaged, False, NULL);
 
       /* Creation du telephone */
@@ -805,7 +814,7 @@ Widget topLevel;
 	  
 	  if (strcmp (item, "blanc") != 0) {
 	      sprintf (buf, "btn_%s", item);
-	      (void)create_pixmap_button (boite_bas, buf, xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)touches[i].code, pixmaps_minitel[i-4], pixmaps_minitel_on[i-4], pixmaps_minitel[i-4], pixmaps_minitel_on[i-4], unsensitive_pixmap_b, NULL);
+	      (void)create_pixmap_button (boite_bas, buf, xpmButtonWidgetClass, (XtCallbackProc)commandes, (XtPointer)touches[i].code, pixmaps_minitel[i-4], pixmaps_minitel_on[i-4], pixmaps_minitel[i-4], pixmaps_minitel_on[i-4], unsensitive_pixmap_b);
 	  }	
       }
 
@@ -1272,28 +1281,3 @@ void activation_bouton_stop ()
     XtSetArg (args[n], XtNstate, True); n++;
     XtSetValues (stop_lecteur, args, n);
 }
-
-#ifdef NOTDEF
-/*
- * Callback des boutons "oui/non_arret_page_lecteur"
- */
-
-static void arret_a_chaque_page (w, flag, call_data)
-Widget w;
-Boolean flag;
-XtPointer call_data;
-{
-    flag_arret_a_chaque_page = flag;
-}
-
-static void type_fin_page (w, type, state)
-Widget w;
-int type;
-Boolean state;
-{
-    if (state)
-	type_de_fin_page |= type;
-    else
-	type_de_fin_page &= ~type;
-}
-#endif
