@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xm.c,v 1.10 1996/10/31 12:59:46 pierre Exp $";
+static char rcsid[] = "$Id: xm.c,v 1.11 1997/01/08 15:03:18 pierre Exp $";
 
 /*
  * Couche Toolkit OSF-MOTIF
@@ -188,7 +188,11 @@ XtPointer call_data;
 	case 2 :
 	   type_de_fin_page = ARRET_SUITE;
 	  break;
-	  
+
+	case 3 :
+	   type_de_fin_page = ARRET_SUITE | ARRET_FF;
+	  break;
+	    
 	default :
 	    break;
       }
@@ -560,7 +564,7 @@ Widget topLevel;
     XtManageChild (compteur_lecteur_page);
 
     /* Condition d'arret */
-    menu_type_arret_page = XmVaCreateSimpleOptionMenu (rc_lecteur, "menu_type_arret_page", NULL, 0, 0, (XtCallbackProc)menu_type_arret_page_cb, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, NULL); 
+    menu_type_arret_page = XmVaCreateSimpleOptionMenu (rc_lecteur, "menu_type_arret_page", NULL, 0, 0, (XtCallbackProc)menu_type_arret_page_cb, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, XmVaPUSHBUTTON, NULL, 0, NULL, NULL, NULL); 
     XtManageChild (menu_type_arret_page);
 
     /* Bouton 'Quitte' */
