@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xtel.c,v 1.14 1996/10/28 13:38:34 pierre Exp $";
+static char rcsid[] = "$Id: xtel.c,v 1.15 1997/01/08 15:03:40 pierre Exp $";
 
 /*
  * programme principal 
@@ -450,9 +450,11 @@ char **av;
     while (i < ac) {
 	if (strcmp (av[i], "-e") * strcmp (av[i], "--exec-procedure") == 0)
 	    procedure_executee = av[++i];
-	else {
+	else if (av[i][0] != '-') {
 	    strcpy (nom_fichier_charge, av[i]);
 	}
+	else
+	    Usage ();
 
 	i++;
     }
