@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-#ident "$Id: xtel.h,v 1.5 1996/09/22 21:10:26 pierre Exp $"
+#ident "$Id: xtel.h,v 1.6 1997/02/25 15:53:38 pierre Exp $"
 
 #ifndef _xtel_h
 #define _xtel_h
@@ -26,6 +26,7 @@
  * definition des constantes
  */
 #include <stdio.h>
+#include <stdlib.h>
 #include <fcntl.h>
 #ifdef NO_NETWORK
 #include <sys/socket.h>
@@ -37,8 +38,6 @@ struct sockaddr_un unaddr;
 #include <X11/StringDefs.h>
 #include <X11/Xos.h>
 
-extern char *getenv();
-
 #include "demon.h"
 
 /* le widget Videotex */
