@@ -17,7 +17,7 @@
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
-static char rcsid[] = "$Id: xteld.c,v 1.20 1996/10/31 13:03:52 pierre Exp $";
+static char rcsid[] = "$Id: xteld.c,v 1.25 1997/02/21 17:02:42 pierre Exp $";
 
 /*
  * Demon XTELD (communication avec le MODEM)
@@ -39,6 +39,11 @@ static char rcsid[] = "$Id: xteld.c,v 1.20 1996/10/31 13:03:52 pierre Exp $";
  *   Vincent Gillet
  *
  *	- dialogue avec client Window$ (option -w)
+ *
+ *   Eric Delaunay
+ *
+ *	- support IAN
+ *
  */
 
 #define EXTERN
@@ -118,6 +123,10 @@ static char flag_connexion;
 static char parite;
 static Boolean flag_serveur_local, flag_crlf, flag_windaube;
 static int tuyau_in[2], tuyau_out[2];
+static int temps_maxi;
+static int detecte_ian;
+static int saisie_active;
+static char fin_connexion = 0;
 
 /* Syslog or not syslog ? */
 #ifdef USE_SYSLOG
@@ -147,11 +156,12 @@ int  p1, p2, p3, p4, p5, p6, p7;
 }
 #endif /* USE_SYSLOG */
 
-void demande_fin_fils()
+static void demande_fin_fils()
 {
 #ifdef DEBUG_XTELD
     log_debug ("Demande la fin du fils");
 #endif
+    signal (SIGALRM, SIG_IGN);
     fin_fils = 1;
 }
 
@@ -172,7 +182,6 @@ int code_erreur;
     write (XTELD_OUTPUT, &e, 1);
     write (XTELD_OUTPUT, CHAINE_REPONSE_FIN_ERREUR, 1);
 }
-
 /* 
  * Teste si l'utilisateur courant a acces au service demande
  *
@@ -180,25 +189,65 @@ int code_erreur;
  *	0 sinon
  */
 int
-service_autorise(indice_service) 
-int indice_service;
-{    char *pt;
+service_autorise (indice_service, maxtime) 
+int indice_service, *maxtime;
+{    char *pt, *pt1, *auth = definition_services[indice_service].autorisations;
      char autorisations[2048];
+     int default_maxtime = 0;
 
-     if (definition_services[indice_service].autorisations[0]== '\000')
-       return(1);
+     *maxtime = 0;
 
-     strcpy(autorisations, definition_services[indice_service].autorisations);
-     pt = strtok(autorisations, ":");
+     /* Pas de protection ou definition general du temps maxi */
+     if (*auth == 0)
+       return 1;
+
+     if (*auth == '=' && !strchr (auth, ':')) {
+       *maxtime = atoi (auth+1);
+       return 1;
+     }
+
+     strcpy (autorisations, auth);
+     pt = strtok (autorisations, ":");
      while (pt != NULL) {
-       if (strcmp (pt, utilisateur) == 0) {
-           return(1);
+       /* 
+	* Format: nom=temps_maxi (si =temp_maxi, le temps est la valeur 
+	* par defaut)
+	*/
+       *maxtime = default_maxtime;
+
+       if (*pt == '=') {
+	 /* nouvelle valeur par defaut */
+	 *maxtime = default_maxtime = atoi (pt+1);
        }
+       else {
+	 if ((pt1 = strchr (pt, '='))) {
+	   *pt1 = 0;
+	   *maxtime = atoi (pt1+1);
+	 }
+
+	 if (strcmp (pt, utilisateur) == 0) {
+           return(1);
+	 }
+       }
+
        pt = strtok(NULL, ":");
      }
      return(0);
 }
 
+/*
+ * Fonction d'autorisation d'envoi de caractres au modem
+ * (quand connexion restreinte  un service Teletel)
+ */
+static void active_saisie ()
+{
+#ifdef DEBUG_XTELD
+    log_debug( "saisie autorise" );
+#endif
+    saisie_active = 1;
+    signal( SIGUSR1, SIG_DFL );
+}
+
 /*
  * Fonction de deconnexion (appelee sur SIGCHLD)
  */
@@ -209,7 +258,7 @@ static void waitchild ()
     wait (&r);
 }
 
-void deconnexion ()
+static void deconnexion ()
 {
     FILE *fplog;
 
@@ -257,6 +306,7 @@ void deconnexion ()
     }
 
     waitchild ();
+    fin_connexion++;
 }
 
 /* Test de la mort subite de Xtel (errno == 2) en cours de connexion */
@@ -308,36 +358,61 @@ char c;
     return NULL;
 }
 
+/* Trouve le device associe a un numero de telephone */
+static char *find_device (service)
+char *service;
+{
+  register int i, idev;
+  char *numero_direct;
+
+  /* On precise le device "a la main" (ex: 1234,/dev/cua0) */
+  numero_direct = strchr (service, ',');
+	
+  /* Nom du device associe au service */
+  if (numero_direct) {
+    *numero_direct++ = 0;
+    return (numero_direct);
+  }
+  else {
+    for (i = 0 ; i != nb_services ; i++) {
+      if (!strcmp (definition_services[i].nom_service, "Direct"))
+	  idev = i;
+      if (!strcmp (definition_services[i].nom_uucp, service)) {
+	idev = i;
+	break;
+      }
+    }
+
+    (void)service_autorise (idev, &temps_maxi);
+#ifdef DEBUG_XTELD
+      log_debug ("find_device: %s tmax %d", definition_services[idev].device, temps_maxi);
+#endif
+    return (definition_services[idev].device);
+  }
+}
+
 /* 
  * Connexion a un service 
  */
 void appel_service (service_teletel)
 char *service_teletel;
 {
-    char *device_associe = NULL, *numero_direct, *option = NULL;
+    char *device_associe = NULL, *option = NULL;
+    char *code_service = NULL;
     FILE *fplog;
     register int i;
 
+    detecte_ian = 0;
+    saisie_active = 0;
+
 #ifdef DEBUG_XTELD
     log_debug ("connexion au service %s utilisateur %s", service_teletel, utilisateur);
 #endif
 
     signal (SIGTERM, demande_fin_fils);
 
-    /* Est-ce un numero direct */
-    numero_direct = strchr (service_teletel, ',');
-	
-    /* Nom du device associe au service */
-    if (numero_direct) {
-	*numero_direct++ = 0;
-	device_associe = numero_direct;
-    }
-    else {
-	for (i = 0 ; i != nb_services ; i++) {
-	    if (strcmp (definition_services[i].nom_uucp, service_teletel) == 0)
-		device_associe = definition_services[i].device;
-	}
-    }
+    /* Calcul du device associe */
+    device_associe = find_device (service_teletel);
 
     /* Service local par "pipe" */
     if (device_associe != NULL && strncmp (device_associe, "@pipe", 5) == 0) {
@@ -413,17 +488,39 @@ char *service_teletel;
     else
 #endif
       { /* Connexion MODEM */
-	if ((fd_modem = mydial(service_teletel, device_associe)) < 0) {
+	/*
+	 * spare tlphone et code service (nnnn:code)
+	 */
+	char *telno = strdup(service_teletel);
+	code_service = strchr( telno, ':' );
+	if (code_service) {
+	    *code_service = 0;
+	    code_service = strchr( service_teletel, ':' ) + 1;
+	    detecte_ian = IAN_DE_GARDE;	/* attente capture code d'entre sur le service */
+	    ian_init( telno );
+	    signal( SIGUSR1, active_saisie );
+	}
+	else {
+	    saisie_active = 1;
+	}
+	/*
+	 * compose le numro
+	 */
+#ifdef DEBUG_XTELD
+	log_debug( "service appel : %s [%s]", telno, code_service?code_service:"" );
+#endif
+	if ((fd_modem = mydial(telno, device_associe)) < 0) {
 #ifdef DEBUG_XTELD
 	    log_debug ("meurt (erreur)");
 #endif
 	    exit (1);
 	}
+	free(telno);
     }
 
     /* valide le signal de deconnexion */
     signal (SIGCHLD, deconnexion);
-
+    
     /* Init masque select */
     FD_ZERO (&a_lire);	
     FD_SET (fd_modem, &a_lire);
@@ -434,6 +531,17 @@ char *service_teletel;
 	
     flag_connexion = 1;	/* On est connecte ! */
 	
+    /* Envoi du temps maxi de connexion */
+    if (temps_maxi) {
+      char l;
+
+      write (XTELD_OUTPUT, CHAINE_TEMPS_MAXI, 1);
+      sprintf (buf, "%d", temps_maxi);
+      l = strlen(buf);
+      write (XTELD_OUTPUT, &l, 1);
+      write (XTELD_OUTPUT, buf, l);
+    }
+
     /* signale la connexion a XTEL */
     write (XTELD_OUTPUT, CHAINE_REPONSE_CONNEXION, 1);
 
@@ -448,6 +556,12 @@ char *service_teletel;
 	int ignore = 0;
 	int code_fin = 1;
 
+	/* Duree maxi autorisee */
+	if (!flag_serveur_local && temps_maxi > 0) {
+          signal (SIGALRM, demande_fin_fils);
+	  alarm (temps_maxi);
+	}
+
 	fin_fils = 0;
 	while (!fin_fils) {
 	    int nread, size, i;
@@ -483,6 +597,59 @@ char *service_teletel;
 		break;
 	    }
 	    
+	    /*
+	     * termine la connexion lors du retour  la page
+	     * du service Teletel (detecte_ian == 1)
+	     * ou autorise le service (detecte_ian == 2).
+	     */
+	    if (detecte_ian) {
+		int ian;
+
+		for( i = 0 ; i < size ; i++ )
+		    if (ian = ian_valide( detecte_ian, buf[i] )) {
+			switch (detecte_ian) {
+			case IAN_DE_GARDE:
+#ifdef DEBUG_XTELD
+			    log_debug( "Emission code du service : %s + ENVOI", code_service );
+#endif
+			    /* ecrit le code du service */
+			    write ((flag_serveur_local ? tuyau_out[1] : fd_modem),
+				    code_service, strlen(code_service) );
+			    /* + touche ENVOI */
+			    write ((flag_serveur_local ? tuyau_out[1] : fd_modem),
+				    "\023A", 2 );
+			    detecte_ian = IAN_D_ENTREE;  /* autorise le service */
+			    break;
+			case IAN_D_ENTREE:
+			    if (ian == 1) {
+#ifdef DEBUG_XTELD
+				log_debug( "service activ. Envoi SIGUSR1 pid %d", getppid() );
+#endif
+				detecte_ian = IAN_DE_FIN;
+				/*
+				 * autorise le pre  transmettre les actions
+				 * au fils, maintenant que le service a t valid
+				 */
+				kill( getppid(), SIGUSR1 );
+			    }
+			    else {
+				/* devrait faire une nouvelle tentative ? */
+#ifdef DEBUG_XTELD
+				log_debug( "accs refus" );
+#endif
+				fin_fils = 1;	/* chec */
+			    }
+			    break;
+			case IAN_DE_FIN:
+#ifdef DEBUG_XTELD
+			    log_debug( "retour  la page Teletel" );
+#endif
+			    fin_fils = 1;     /* termine la connexion */
+			}
+			break;
+		    }
+	    }
+
 	    for (i = 0; i < size; i++) {
 		if (definition_lignes[numero_ligne].cs != CS8)
 		    buf[i] &= 0x7f;
@@ -530,6 +697,7 @@ char *service_teletel;
 		    else
 			buf1[size1++] = buf[i];
 		}
+
 		write (XTELD_OUTPUT, buf1, size1);
 	    }
 	    else
@@ -653,7 +821,6 @@ int lire_initial(ch)
 char *ch;
 {
     int ret,indice_service;
-    unsigned char l;
     char *ptr;
 
     /* Demande d'identification */
@@ -676,7 +843,7 @@ char *ch;
 	strcpy (ch, "windaube");
 
 	for (indice_service=0; indice_service != nb_services; indice_service++) {
-	    if (service_autorise (indice_service)) {
+	    if (service_autorise (indice_service, &temps_maxi)) {
 		sprintf (buf, "%2d - %s\r\n", indice_service, definition_services[indice_service].nom_service);
 		write_chaine_sans_accent (buf);
 	    }
@@ -698,7 +865,7 @@ char *ch;
 #ifdef DEBUG_XTELD
 	log_debug ("lu : %s",buf);
 #endif
-	if (atoi(buf) > nb_services || ! service_autorise (atoi(buf))) {
+	if (atoi(buf) > nb_services || ! service_autorise (atoi(buf), &temps_maxi)) {
 	    sprintf (buf, "\r\n\r\n ** Choix interdit ! **\r\n");
 	    write (XTELD_OUTPUT, buf, strlen(buf));
 	    goto err;
@@ -715,14 +882,6 @@ char *ch;
 	return 1;
     }
 
-    ch[l] = 0;
-
-    while (l) {
-	ret = read (XTELD_INPUT, ch, l);
-	if (ret < 0) goto err;
-	l -= ret;
-    }
-
     return 0;
 
 err:
@@ -743,7 +902,6 @@ int ac;
 char **av;
 {
     unsigned char c;
-    char fin_connexion = 0;
     register int i;
 #ifdef NO_NETWORK
     int sock_ecoute, retry;
@@ -916,8 +1074,13 @@ char **av;
 	    }
 
 	    /* lecture connexion XTEL */
-	    while (!fin_connexion && read (XTELD_INPUT, &c, 1) == 1) {
-
+	    while (!fin_connexion) {
+		if (read (XTELD_INPUT, &c, 1) <= 0) {
+		    if (errno == EINTR)
+			continue;
+		    else
+			break;
+		}
 		if (flag_connexion) {
 		    if (c == VALEUR_COMMANDE_FIN) {
 #ifdef DEBUG_XTELD
@@ -938,7 +1101,19 @@ char **av;
 			    c = (c & 0x7f) | (p << 7);
 			}
 #endif /* NO_TERMIO */
-			write ((flag_serveur_local ? tuyau_out[1] : fd_modem), &c, 1);
+			/*
+			 * on crit sur le modem que lorsque le code de service
+			 * a t entr o qu'il n'y en a pas.
+			 */
+			if (flag_serveur_local)
+			    write ( tuyau_out[1], &c, 1 );
+			else
+			    if (saisie_active)
+				write ( fd_modem, &c, 1);
+#ifdef DEBUG_XTELD
+			    else
+				log_debug( "saisie perdue : `%c' (%d)", c, c );
+#endif
 		    }
 		}
 		else {
@@ -965,7 +1140,7 @@ char **av;
 			if ((indice_service == nb_services) || flag_m1)
 			    write (XTELD_OUTPUT, CHAINE_REPONSE_PLUS_DE_SERVICE, 1);
 			else {
-			    if (service_autorise (indice_service)) {
+			    if (service_autorise (indice_service, &temps_maxi)) {
 				c = strlen (definition_services[indice_service].nom_service);
 				write (XTELD_OUTPUT, &c, 1);
 				write (XTELD_OUTPUT, definition_services[indice_service].nom_service, c);
@@ -1024,7 +1199,7 @@ fin_xteld:
 #else
 
 #ifdef DEBUG_XTELD
-    log_debug ("%d meurt (OK), errno = %d ICI", getpid(), errno);
+    log_debug ("%d meurt (OK), errno = %d", getpid(), errno);
 #endif
 
     /* Si xtel a ete tue sauvagement, tue le fils */
